<?PHP
session_start();

/* load settings */
include_once('conf/config.php');
include_once('conf/ELOconfig.php');
include_once('lib/utils.php');

CheckSession();

/* define constants */
include_once('lib/chessconstants.php');

/* include outside functions */
include_once('lib/dbwrapper.php');
include_once('lib/chessutils.php');
include_once('lib/gui.php');
include_once('lib/chessdb.php');
include_once('lib/chat.php');


/* check if loading game */
if (isset($_POST['gameID'])){
    $_SESSION['gameID'] = $_POST['gameID'];
    $_SESSION['perspect'] = "";
}

/* debug flag */
define ("DEBUG", 0);


/* load game */
$isInCheck = ($_POST['isInCheck'] == 'true');
$isCheckMate = false;
$isPromoting = false;
$isUndoing = false;
loadHistory();
loadGame();
processMessages();
	
// save player's message into the database
saveMessage();

if ($isUndoing)	{
    doUndo();
    saveGame();
}elseif (($_POST['promotion'] != "") && ($_POST['toRow'] != "") && ($_POST['toCol'] != "")){
    savePromotion();
    $board[$_POST['toRow']][$_POST['toCol']] = $_POST['promotion'] | ($board[$_POST['toRow']][$_POST['toCol']] & BLACK);
    saveGame();
}elseif (($_POST['fromRow'] != "") && ($_POST['fromCol'] != "") && ($_POST['toRow'] != "") && ($_POST['toCol'] != "")){
    /* ensure it's the current player moving				 */
    /* NOTE: if not, this will currently ignore the command...               */
    /*       perhaps the status should be instead?                           */
    /*       (Could be confusing to player if they double-click or something */
    $tmpIsValid = true;
    if (($numMoves == -1) || ($numMoves % 2 == 1)){
	/* White's move... ensure that piece being moved is white */
	if ((($board[$_POST['fromRow']][$_POST['fromCol']] & BLACK) != 0) || ($board[$_POST['fromRow']][$_POST['fromCol']] == 0))
	    /* invalid move */
	    $tmpIsValid = false;
    }else{
	/* Black's move... ensure that piece being moved is black */
	if ((($board[$_POST['fromRow']][$_POST['fromCol']] & BLACK) != BLACK) || ($board[$_POST['fromRow']][$_POST['fromCol']] == 0))
	    /* invalid move */
	    $tmpIsValid = false;
    }

    if ($tmpIsValid){
	saveHistory();
	doMove();
	saveGame();
    }
}

############################################################
function dispPageTitle() {
############################################################
Global $numMoves, $playersColor, $isPlayersTurn, $isGameOver;

    /* find out if it's the current player's turn */
    if (( (($numMoves == -1) || (($numMoves % 2) == 1)) && ($playersColor == "white"))
			|| ((($numMoves % 2) == 0) && ($playersColor == "black")))
    	$isPlayersTurn = true;
    else
    	$isPlayersTurn = false;

    if ($_SESSION['isSharedPC'])
    	echo "<title>WebChessNG</title>\n";
    else if (!$isGameOver)
	if($isPlayersTurn)
    	    echo "<title>WebChessNG - ".$_SESSION['TXT']['YourTurn']."</title>\n";
    	else
    	    echo "<title>WebChessNG - ".$_SESSION['TXT']['OppTurn']."</title>\n";
    else
	echo "<title>WebChessNG</title>\n";
}

############################################################
function dispMetaInfo() {
############################################################
Global $numMoves,$playersColor, $isPlayersTurn;
    echo "<meta HTTP-EQUIV='Pragma' CONTENT='no-cache'>\n";

    /* if it's not the player's turn, enable auto-refresh */
    if (!$isPlayersTurn && !isBoardDisabled() && !$_SESSION['isSharedPC']){
    	echo "<META HTTP-EQUIV=Refresh CONTENT='";
    	if ($_SESSION['pref_autoreload'] >= $CFG_MINAUTORELOAD)
	    echo $_SESSION['pref_autoreload'];
    	else
	    echo $CFG_MINAUTORELOAD;
	echo "; URL=chess.php?autoreload=yes'>\n";
    }
}

############################################################
function dispJSChessPage(){
############################################################
global $isGameOver;
    echo "<script type='text/javascript'>\n";
    echo "/* transfer board data to javacripts */\n";
    writeJSboard();
    writeJShistory();
    writeJSStr();
    echo "if (DEBUG)\n";
    echo " alert(\"Game initilization complete!\");\n";
    echo "</script>\n";
    echo "<!-- replay history functionality -->\n";
    if ($isGameOver) {
   	writeJSReplayHistory();
   	initBoard();
    }
    echo "<script type='text/javascript' language='javascript'>\n";
    echo " function init(){\n";

    if ($isGameOver){
	echo "  MoveToEnd();\n";
    }
    echo " }\n";
    echo "</script>\n";
    echo "<!-- end replay history functionality -->\n";
    echo "<script type='text/javascript' src='javascript/chessutils.js'>\n";
    echo " /* these are utility functions used by other functions */\n";
    echo "</script>\n";
    echo "<script type='text/javascript' src='javascript/commands.js'>\n";
    echo "// these functions interact with the server\n";
    echo "</script>\n";
    echo "<script type='text/javascript' src='javascript/validation.js'>\n";
    echo "// these functions are used to test the validity of moves\n";
    echo "</script>\n";
    echo "<script type='text/javascript' src='javascript/isCheckMate.js'>\n";
    echo "// these functions are used to test the validity of moves\n";
    echo "</script>\n";
    echo "<script type='text/javascript' src='javascript/squareclicked.js'>\n";
    echo "// this is the main function that interacts with the user everytime they click on a square\n";
    echo "</script>\n";
}

############################################################
function dispCapt() {
############################################################
    $selStr = "curPiece,curColor,replaced";
    $wheStr = "replaced > '' and gameID =  '".$_SESSION['gameID']."'";
    $ordStr = "curColor DESC, replaced DESC";
    $c=0;
    $d=0;
    $f = SelGamesHistory($selStr,$wheStr,$ordStr);
    if (GetNumRows($f) != 0){
    	echo "<table class='tabbord1'  width='560'>\n";
    	echo " <tr><th class='th_std'>".$_SESSION['TXT']['CaptPieces'].":</th></tr>\n";
    	echo " <tr class='tr_std'><td>\n";

    	while($row=GetFetchArray($f)){
    	    if(ereg("white",$row['curColor'])){
	    	$color="black_";
	    	$c++;
    	    }else{
	    	$color="white_";
    	    }
            if($c==1){
	    	echo"  </td></tr><tr class='tr_std'><td>\n";
	    	$d=0;
    	    }
            $d++;

    	    echo"<img src='template/".$_SESSION['pref_theme']."/images/".$color.$row['replaced'].".gif' height='30' width='30' >\n";
#    	    if(($d%8)==0){ echo "<BR>\n"; }
    	} // End while
    	echo "</td></tr></table>\n";
	echo "<br>\n";
    }
}


############################################################
function dispChessPage() {
############################################################
Global $isPromoting, $isUndoRequested, $isDrawRequested, $isGameOver;
    echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n";
    echo "<html><head>\n";
    echo "<meta http-equiv='content-type' content='text/html; charset=UTF-8'>\n";
    dispPageTitle();   
    echo "<link rel='stylesheet' type='text/css' href='template/".$_SESSION['pref_theme']."/webchess.css'>\n";
    dispMetaInfo();
    dispJSChessPage();
    echo "</head><body onload='init()'><br>\n";

    $tmpNick = SelGen("login_name","".$GLOBALS[UserTB].",".$GLOBALS[GamesTB]."","id = whitePlayer AND gameID = ".$_SESSION['gameID']."");
    $WhiteNick = GetFetchArray($tmpNick);
    $tmpNick = SelGen("login_name","".$GLOBALS[UserTB].",".$GLOBALS[GamesTB]."","id = blackPlayer AND gameID = ".$_SESSION['gameID']."");
    $BlackNick = GetFetchArray($tmpNick);

    echo "<center>\n";
    $pagetitel = "".$_SESSION['TXT']['Game']." ".$_SESSION['gameID']."";
    displayMenu($pagetitel); 
    echo "<table class='tabbord3' width='80%'>\n";
    echo " <tr valign='top' align='center'>\n";
    echo "  <td>\n";
    echo "    <form name='gamedata' method='post' action='chess.php'>\n";

    echo "<table class='tabbord1' width='560' cellpadding='3'>\n";
    echo " <tr><th class='th_std' width='10%'></th><th class='move_white2' width='35%'>".$WhiteNick['login_name']."</th><th class='th_std' width='10%'>vs</th><th class='move_black2' width='35%'>".$BlackNick['login_name']."</th><th class='th_std' width='10%'></th></tr>\n";
    echo " <tr class='th_std'><td align='center' colspan='5'>\n";



    drawboard(); 

    echo "  </td></tr>\n";
    echo " <tr class='th_std'><td align='center' colspan='5'>\n";
    
    echo "    <nobr>\n";
    if ($isGameOver){
    	echo "    <input class='button1' type='button'  value='|<' onClick='MoveToStart(); return false;'>\n";
	echo "    <input class='button1' type='button'  value='<<' onClick='BackMove(); return false;'>\n";
    }

    echo "    <input class='button1' type='button' name='btnReload' value='".$_SESSION['TXT']['BtnReload']."' onClick=\"window.open('chess.php','_self')\">\n";
    
    $isDisabled = isBoardDisabled();
    if (!$isGameOver){
    	echo "    <input class='button1' type='button' name='btnUndo' value='".$_SESSION['TXT']['BtnUndo']."' ";
    	if ($isDisabled) 
	    echo "disabled='yes' >\n"; 
    	else 
	    echo "onClick='undo()'>\n";
    	echo "    <input class='button1' type='button' name='btnDraw' value='".$_SESSION['TXT']['BtnDraw']."' ";
    	if ($isDisabled) 
	    echo "disabled='yes' >\n"; 
    	else 
	    echo "onClick='draw()'>\n";
    	echo "    <input class='button1' type='button' name='btnResign' value='".$_SESSION['TXT']['BtnResign']."' ";
    	if ($isDisabled) 
	    echo "disabled='yes' >\n"; 
    	else 
 	    echo "onClick='resigngame()'>\n";
    }
    echo "    <input class='button1' type='button' name='btnPGN' value='".$_SESSION['TXT']['BtnPGN']."' onClick=\"window.open('openpgn.php','_self')\">\n";

    if ($isGameOver){
    	echo "    <input class='button1' type='button'  value='>>' onClick='NextMove(); return false;'>\n";
	echo "    <input class='button1' type='button'  value='>|' onClick='MoveToEnd(); return false;'>\n";
    }

    echo "	</nobr>\n";

    echo "  </td></tr>\n";
    echo "</table>\n";

    echo "    <input type='hidden' name='perspect' value=''>\n";
    echo "    <input type='hidden' name='requestUndo' value='no'>\n";
    echo "    <input type='hidden' name='requestDraw' value='no'>\n";
    echo "    <input type='hidden' name='resign' value='no'>\n";
    echo "    <input type='hidden' name='fromRow' value='";
    if (isPromoting) echo $_POST['fromRow']; 
    echo "'>\n";
    echo "    <input type='hidden' name='fromCol' value='";
    if (isPromoting) echo $_POST['fromCol'];
    echo"'>\n";
    echo "    <input type='hidden' name='toRow' value='";
    if (isPromoting) echo $_POST['toRow']; 
    echo"'>\n";
    echo "    <input type='hidden' name='toCol' value='";
    if (isPromoting) echo $_POST['toCol'];
    echo"'>\n";
    echo "    <input type='hidden' name='isInCheck' value='false'>\n";
    echo "    <input type='hidden' name='isCheckMate' value='false'>\n";
    echo "   </form>\n";

    // Display captured pieces..
    dispCapt();

    showChatWindow();
    
    echo "  </td><td>\n";
    writeStatus(); 
    writeHistory(); 
    echo "  </td></tr>\n";
    echo "</table>\n";
    echo "<br>\n";
    
    dispfootNote();

    echo "</center>\n";
    echo "</body></html>\n";
}


dispChessPage();

?>

