CREATE TABLE `user` (
  `id` int(11) NOT NULL auto_increment,
  `login_name` varchar(20) collate utf8_unicode_ci NOT NULL,
  `login_password` varchar(32) collate utf8_unicode_ci NOT NULL,
  `first_name` varchar(20) collate utf8_unicode_ci NOT NULL,
  `last_name` varchar(20) collate utf8_unicode_ci NOT NULL,
  `user_group_id` int(11) NOT NULL default '2',
  `regmail` varchar(50) collate utf8_unicode_ci NOT NULL,
  `registration` datetime NOT NULL,
  `last_online` datetime NOT NULL,
  `active` tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE `user_group` (
  `id` int(11) NOT NULL auto_increment,
  `description` varchar(20) NOT NULL,
  `active` tinyint(1) NOT NULL default '1',
  PRIMARY KEY  (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

INSERT INTO `user_group` (`id`, `description`, `active`) VALUES 
(1, 'Administrator', 1),
(2, 'Player', 1);

CREATE TABLE `user_messages` (
  `id` int(11) NOT NULL auto_increment,
  `from_user_id` int(11) NOT NULL,
  `to_game_id` int(11) NOT NULL,
  `to_user_id` int(11) NOT NULL,
  `message` text NOT NULL,
  `dateSent` int(11) NOT NULL,
  `unread` tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE `user_profile` (
  `user_id` int(11) unsigned NOT NULL default '0',
  `language_id` tinyint(2) NOT NULL default '1',
  `history` enum('pgn','verbous') NOT NULL default 'pgn',
  `theme` enum('beholder','plain') NOT NULL default 'beholder',
  `email` varchar(50) collate utf8_unicode_ci NOT NULL,
  `emailnotify` tinyint(1) NOT NULL default '0',
  `autoreload` smallint(3) NOT NULL,
  `bsize` smallint(2) NOT NULL default '50',
  PRIMARY KEY  (`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE `user_statistic` (
  `id` int(11) NOT NULL default '0',
  `user_id` int(11) NOT NULL,
  `game_id` int(11) NOT NULL,
  `elo_rate` smallint(4) NOT NULL,
  `elo_change` tinyint(4) NOT NULL,
  `user_id_opp` int(11) NOT NULL,
  `user_color` enum('W','B') NOT NULL,
  `result` enum('W','L','R','A') NOT NULL,
  `game_abort` tinyint(1) NOT NULL,
  `turn_freq` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE `version` (
  `software` varchar(5) NOT NULL,
  `database` varchar(5) NOT NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

INSERT INTO `version` (`software`, `database`) VALUES 
('1.1', '1.1');

CREATE TABLE `language` (
  `id` tinyint(2) NOT NULL auto_increment,
  `description` varchar(20) NOT NULL,
  `short_description` varchar(2) NOT NULL,
  `active` tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

INSERT INTO `language` (`id`, `description`, `short_description`, `active`) VALUES 
(1, 'English', 'en', 1),
(2, 'Deutsch', 'de', 1);

CREATE TABLE `games` (
  `gameID` int(11) NOT NULL auto_increment,
  `whitePlayer` int(11) NOT NULL,
  `blackPlayer` int(11) NOT NULL,
  `gameMessage` enum('playerInvited','inviteDeclined','draw','playerResigned','checkMate') default NULL,
  `messageFrom` enum('black','white') default NULL,
  `dateCreated` datetime NOT NULL,
  `lastMove` datetime NOT NULL,
  `msgforW` tinyint(1) NOT NULL default '0',
  `msgforB` tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (`gameID`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE `games_history` (
  `timeOfMove` datetime NOT NULL,
  `gameID` int(11) NOT NULL,
  `curPiece` enum('pawn','bishop','knight','rook','queen','king') NOT NULL,
  `curColor` enum('white','black') NOT NULL,
  `fromRow` tinyint(2) NOT NULL,
  `fromCol` tinyint(2) NOT NULL,
  `toRow` tinyint(2) NOT NULL,
  `toCol` tinyint(2) NOT NULL,
  `replaced` enum('pawn','bishop','knight','rook','queen','king') default NULL,
  `promotedTo` enum('pawn','bishop','knight','rook','queen','king') default NULL,
  `isInCheck` tinyint(1) NOT NULL,
  `isEnPassant` tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (`timeOfMove`,`gameID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE `games_messages` (
  `msgID` int(11) NOT NULL auto_increment,
  `gameID` int(11) NOT NULL,
  `msgType` enum('undo','draw') NOT NULL,
  `msgStatus` enum('request','approved','denied') NOT NULL,
  `destination` enum('black','white') NOT NULL,
  PRIMARY KEY  (`msgID`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

CREATE TABLE `games_pieces` (
  `gameID` int(11) NOT NULL,
  `color` enum('white','black') NOT NULL,
  `piece` enum('pawn','rook','knight','bishop','queen','king') NOT NULL,
  `col` tinyint(2) NOT NULL,
  `row` tinyint(2) NOT NULL,
  KEY `gameID` (`gameID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;