<?PHP	

require_once('lib/dbwrapper.php');

/* these are utility functions used by other functions */
############################################################
function getPieceName($piece){
############################################################
    switch($piece & COLOR_MASK)	{
	case PAWN: 	$name = "pawn"; 	break;
	case KNIGHT: 	$name = "knight";	break;
	case BISHOP:	$name = "bishop";	break;
	case ROOK:	$name = "rook";		break;
	case QUEEN:	$name = "queen";	break;
	case KING:	$name = "king";		break;
    }
    return $name;
}

############################################################
function getPieceCode($color, $piece){
############################################################
    switch($piece){
	case "pawn":	$code = PAWN;		break;
	case "knight":	$code = KNIGHT;		break;
	case "bishop": 	$code = BISHOP;		break;
	case "rook":	$code = ROOK;		break;
	case "queen":	$code = QUEEN;		break;
	case "king": 	$code = KING;		break;
    }
    if ($color == "black")
	$code = BLACK | $code;
    return $code;
}

############################################################
function getPGNCode($piecename){
############################################################
    switch($piecename){
	case 'pawn':	$pgnCode = "";		break;
	case 'knight':	$pgnCode = "N";		break;
	case 'bishop':	$pgnCode = "B";		break;
	case 'rook':	$pgnCode = "R";		break;
	case 'queen':	$pgnCode = "Q";		break;
	case 'king':	$pgnCode = "K";		break;
	case '':	$pgnCode="";		break;
    }
    return $pgnCode;
}

############################################################
function getPieceNameLang($piece){
############################################################
    switch($piece){
	case "pawn":	return $_SESSION['TXT']['Pawn'];	break;
	case "knight":	return $_SESSION['TXT']['Knight'];	break;
	case "bishop": 	return $_SESSION['TXT']['Bishop'];	break;
	case "rook":	return $_SESSION['TXT']['Rook'];	break;
	case "queen":	return $_SESSION['TXT']['Queen'];	break;
	case "king": 	return $_SESSION['TXT']['King'];	break;
    }
}

############################################################
function isBoardDisabled(){
############################################################
    global $board, $isPromoting, $isUndoRequested, $isDrawRequested, $isGameOver, $playersColor, $requestPending;

    // if current player is promoting, a message needs to be replied to (Undo or Draw) 
    // or the game is over, then board is Disabled 
    $tmpIsBoardDisabled = (($requestPending || $isPromoting || $isUndoRequested || $isDrawRequested || $isGameOver) == true);
	
    /* if opponent is in the process of promoting, then board is diabled */
    if (!$tmpIsBoardDisabled){
	if ($playersColor == "white")
	    $promotionRow = 7;
	else
	    $promotionRow = 0;

	for ($i = 0; $i < 8; $i++)
	    if (($board[$promotionRow][$i] & COLOR_MASK) == PAWN)
		$tmpIsBoardDisabled = true;
    }

    return $tmpIsBoardDisabled;
}

############################################################
function moveToPGNString($curColor, $piece, $fromRow, $fromCol, $toRow, $toCol, $pieceCaptured, $promotedTo, $isChecking){
############################################################
    $pgnString = "";
		
    /* check for castling */
    if (($piece == "king") && (abs($toCol - $fromCol) == 2)){
	/* if king-side castling */
	if (($toCol - $fromCol) == 2)
	    $pgnString .= ("O-O");
	else
	    $pgnString .= ("O-O-O");
    }else{
	/* PNG code for moving piece */
	$pgnString .= getPGNCode($piece);

	/* source square */
	$pgnString .= chr($fromCol + 97).($fromRow + 1);

	/* check for captured pieces */
	if ($pieceCaptured != "")
	    $pgnString .= "x";
	else
	    $pgnString .= "-";

	/* destination square */
	$pgnString .= chr($toCol + 97).($toRow + 1);

	/* check for pawn promotion */
	if ($promotedTo != "")
	    $pgnString .= "=".getPGNCode($promotedTo);
    }
    /* check for CHECK */
    if ($isChecking)
	$pgnString .= "+";

    /* if checkmate, $pgnString .= "#"; */
    return $pgnString;
}

############################################################
function moveToVerbousString($curColor, $piece, $fromRow, $fromCol, $toRow, $toCol, $pieceCaptured, $promotedTo, $isChecked){
############################################################
    $verbousString = "";
		
    /* ex: white queen from a4 to c6 */
    $verbousString .= getPieceNameLang($piece)." ".$_SESSION['TXT']['from']." ".chr($fromCol + 97).($fromRow + 1)." ".$_SESSION['TXT']['to']." ".chr($toCol + 97).($toRow + 1);

    /* check for castling */
    if (($piece == "king") && (abs($toCol - $fromCol) == 2))
	$verbousString .= "<br>".$_SESSION['TXT']['Castled']."";

    /* check for en passant */
    if (($piece == "pawn") && ($toCol != $fromCol) && ($pieceCaptured == ""))
	$verbousString .= "<br>".$_SESSION['TXT']['EatEnPassant']."";
			
    if ($pieceCaptured != "")
	$verbousString .= "<br>".$_SESSION['TXT']['Eating']." ".getPieceNameLang($pieceCaptured);

    if ($promotedTo != "")
	$verbousString .= "<br>".$_SESSION['TXT']['PawnPomoted']." ".getPieceNameLang($promotedTo);
		
    return $verbousString;
}

############################################################	
function coordsToSquare($xRow,$xCol){
############################################################
    $xRow+=1;
    $xCol+=1;
    if($xCol==1) $newCol="a";
    if($xCol==2) $newCol="b";
    if($xCol==3) $newCol="c";
    if($xCol==4) $newCol="d";
    if($xCol==5) $newCol="e";
    if($xCol==6) $newCol="f";
    if($xCol==7) $newCol="g";
    if($xCol==8) $newCol="h";
    return $newCol.$xRow;
}

/* don't delete !!! used for the replay funcionality */
############################################################
function moveToPGNString2($curColor, $piece, $fromRow, $fromCol, $toRow, $toCol, $pieceCaptured, $promotedTo, $isChecking){
############################################################
    $pgnString = "";
		
    /* check for castling */
    if (($piece == "king") && (abs($toCol - $fromCol) == 2)){
	// mark white castling
	if ($curColor == 'white')
	    $pgnString .= 'W';
		         
	/* if king-side castling */
	if (($toCol - $fromCol) == 2)
	    $pgnString .= ("O-O");
	else
	    $pgnString .= ("O-O-O");
    }else{
	/* PNG code for moving piece */
	//$pgnString .= getPGNCode($piece);

	/* source square */
	$pgnString .= chr($fromCol + 97).($fromRow + 1);

	/* check for captured pieces */
	if ($piece='pawn' && $fromCol!=$toCol)
	    $pgnString .="x";
	else{
	    if ($pieceCaptured != "")
	    	$pgnString .= "x";
	    else
		$pgnString .= "";
	}

	/* destination square */
	$pgnString .= chr($toCol + 97).($toRow + 1);

	/* check for pawn promotion */
	if ($promotedTo != "")
	    $pgnString .= "=".getPGNCode($promotedTo);
    }
		
    /* check for CHECK */
    if ($isChecking)
	$pgnString .= "+";

    /* if checkmate, $pgnString .= "#"; */
    return $pgnString;
}

############################################################
function ReturnGameInfo($GameID){
############################################################
    global $pWhite,$pWhiteF,$pWhiteL,$pBlack,$pBlackF,$pBlackL,$gStart,$MyColor,$isDraw;
    
    $selStr = "whitePlayer,blackPlayer,dateCreated,gameMessage";
    $wheStr = "gameID = ".$GameID."";
    $tmpGameQ = SelGames($selStr,$wheStr);
    $tmpGame = GetFetchArray($tmpGameQ);
		
    $gStart = $tmpGame['dateCreated'];
    $isDraw="";
    if($tmpGame['gameMessage']=="draw")
	$isDraw=true;
    else
	$isDraw="";
		
    $tmpBlackQ = SelUser("login_name,first_name,last_name","id = ".$tmpGame['blackPlayer']."");
    $xBlack = GetFetchArray($tmpBlackQ);
    $pBlack = $xBlack['login_name'];
    $pBlackF = $xBlack['first_name'];
    $pBlackL = $xBlack['last_name'];
     
    $tmpWhiteQ = SelUser("login_name,first_name,last_name","id = ".$tmpGame['whitePlayer']."");
    $xWhite = GetFetchArray($tmpWhiteQ);
    $pWhite = $xWhite['Login_name'];
    $pWhiteF = $xWhite['first_name'];
    $pWhiteL = $xWhite['last_name'];

    if ($tmpGame['whitePlayer'] == $_SESSION['playerID']){
	$tmpOpponent = $tmpBlackQ;
	$MyColor="white";
    }elseif ($tmpGame['blackPlayer'] == $_SESSION['playerID']){
	$tmpOpponent = $tmpWhiteQ;
	$MyColor="black";
    }else{
	$MyColor="none";
    }
}

###merge

############################################################
function doUndo(){
############################################################
    global $board, $numMoves;

    /* get the last move from the history */
    /* NOTE: MySQL currently has no support for subqueries */

    $tmpMaxTime = SelGamesHistory("Max(timeOfMove)","gameID = ".$_SESSION['gameID']."");
    $maxTime = GetFetchArray($tmpMaxTime);
    $moves = SelGamesHistory("*","gameID = ".$_SESSION['gameID']." AND timeOfMove = '".$maxTime[0]."'");

    /* if there actually is a move... */
    if ($lastMove = GetFetchArray($moves)){
	/* if the last move was played by this player */
			
	/* undo move */
	$fromRow = $lastMove['fromRow'];
	$fromCol = $lastMove['fromCol'];
	$toRow = $lastMove['toRow'];
	$toCol = $lastMove['toCol'];

	$board[$fromRow][$fromCol] = getPieceCode($lastMove['curColor'], $lastMove['curPiece']);
	$board[$toRow][$toCol] = 0;

	/* check for castling */
	if ((($board[$fromRow][$fromCol] & COLOR_MASK) == KING) && (abs($toCol - $fromCol) == 2)){
	    /* move rook back as well */
	    if (($toCol - $fromCol) == 2){
		$board[$fromRow][7] = $board[$fromRow][5];
		$board[$fromRow][5] = 0;
	    }else{
		$board[$fromRow][0] = $board[$fromRow][3];
		$board[$fromRow][3] = 0;
	    }
	}

	/* restore lost piece */
	if (!is_null($lastMove['replaced'])){
	    /* check for en-passant */
	    if ($lastMove['isEnPassant']){
	    	if ($lastMove['curColor'] == "black")
		    $board[$fromRow][$toCol] = getPieceCode("white", "pawn");
	    	else
		    $board[$fromRow][$toCol] = getPieceCode("black", "pawn");
	    }else{
	    	if ($lastMove['curColor'] == "black")
		    $board[$toRow][$toCol] = getPieceCode("white", $lastMove['replaced']);
	    	else
		    $board[$toRow][$toCol] = getPieceCode("black", $lastMove['replaced']);
	    }
	}

	/* remove last move from history */
	$numMoves--;
	DelGamesHistory("gameID = ".$_SESSION['gameID']." AND timeOfMove = '".$maxTime[0]."'");

	/* else */
	/* output error message */
    }
}


############################################################
function initBoard(){
############################################################
    global $board;

    /* clear board */
    for ($i = 0; $i < 8; $i++){
	for ($j = 0; $j < 8; $j++){
	    $board[$i][$j] = 0;
	}
    }

    /* setup white pieces */
    $board[0][0] = WHITE | ROOK;
    $board[0][7] = WHITE | ROOK;
    $board[0][1] = WHITE | KNIGHT;
    $board[0][6] = WHITE | KNIGHT;
    $board[0][2] = WHITE | BISHOP;
    $board[0][5] = WHITE | BISHOP;
    $board[0][3] = WHITE | QUEEN;
    $board[0][4] = WHITE | KING;

    /* setup black pieces */
    $board[7][0] = BLACK | ROOK;
    $board[7][7] = BLACK | ROOK;
    $board[7][1] = BLACK | KNIGHT;
    $board[7][6] = BLACK | KNIGHT;
    $board[7][2] = BLACK | BISHOP;
    $board[7][5] = BLACK | BISHOP;
    $board[7][3] = BLACK | QUEEN;
    $board[7][4] = BLACK | KING;

    /* setup pawns */
    for ($i = 0; $i < 8; $i++){
	$board[1][$i] = WHITE | PAWN;
	$board[6][$i] = BLACK | PAWN;
    }
}

############################################################
function createNewGame($gameID){
############################################################
    /* clear history */
    global $numMoves;

    $numMoves = -1;
    DelGamesHistory("gameID = ".$_SESSION['gameID']."");
    initBoard();
}

############################################################
function doMove(){
############################################################
    global $board, $isPromoting, $doUndo, $history, $numMoves;
		
    /* if moving en-passant */
    /* (ie: if pawn moves diagonally without replacing anything) */
    if ((($board[$_POST['fromRow']][$_POST['fromCol']] & COLOR_MASK) == PAWN) 
		&& ($_POST['toCol'] != $_POST['fromCol']) 
		&& ($board[$_POST['toRow']][$_POST['toCol']] == 0))
	/* delete eaten pawn */
	$board[$_POST['fromRow']][$_POST['toCol']] = 0;
		
    /* move piece to destination, replacing whatever's there */
    $board[$_POST['toRow']][$_POST['toCol']] = $board[$_POST['fromRow']][$_POST['fromCol']];

    /* delete piece from old position */
    $board[$_POST['fromRow']][$_POST['fromCol']] = 0;

    /* if not Undoing, but castling */
    if (($doUndo != "yes") && (($board[$_POST['toRow']][$_POST['toCol']] & COLOR_MASK) == KING) 
		&& (($_POST['toCol'] - $_POST['fromCol']) == 2)){
	/* castling to the right, move the right rook to the left side of the king */
	$board[$_POST['toRow']][5] = $board[$_POST['toRow']][7];

	/* delete rook from original position */
	$board[$_POST['toRow']][7] = 0;
    }
    elseif (($doUndo != "yes") && (($board[$_POST['toRow']][$_POST['toCol']] & COLOR_MASK) == KING) 
		&& (($_POST['fromCol'] - $_POST['toCol']) == 2)){
	/* castling to the left, move the left rook to the right side of the king */
	$board[$_POST['toRow']][3] = $board[$_POST['toRow']][0];

	/* delete rook from original position */
	$board[$_POST['toRow']][0] = 0;
    }
    return true;
}
?>
